# pysideprocessing

Pysideprocessing implements processing.org in the python language with pyside6 as gui component.

Processing.org is a wonderful tool, but it's python version builds upon jython, which lacks a lot of features introduced since python 3 release.

It is intended for educational purposes, so for now only features used in my classes have been implemented. More features will follow, but some might never be implemented.

